<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:marc="http://www.loc.gov/MARC21/slim" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns="http://purl.org/dc/elements/1.1/" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" exclude-result-prefixes="marc">
	<xsl:import href="MARC21slimUtils.xsl"/>
	<xsl:output method="xml" encoding="UTF-8" indent="yes"/>
	<xsl:param name="destfile"></xsl:param>

	<xsl:template match="/">
		<dublin_core>
			<xsl:apply-templates/>
		</dublin_core>
	</xsl:template>
	
	<xsl:template match="marc:record">
		<xsl:variable name="leader" select="marc:leader"/>
		<xsl:variable name="leader6" select="substring($leader,7,1)"/>
		<xsl:variable name="leader7" select="substring($leader,8,1)"/>
		<xsl:variable name="controlField008" select="marc:controlfield[@tag=008]"/>

	  
			<xsl:for-each select="marc:datafield[@tag=245]">
				<dcvalue element="title" qualifier="none">
					<xsl:call-template name="subfieldSelect">
						<xsl:with-param name="codes">abfghk</xsl:with-param>
					</xsl:call-template>
				</dcvalue>
			</xsl:for-each>

	
			<xsl:for-each select="marc:datafield[@tag=100]|marc:datafield[@tag=110]|marc:datafield[@tag=111]|marc:datafield[@tag=700]|marc:datafield[@tag=710]|marc:datafield[@tag=711]|marc:datafield[@tag=720]">
				<dcvalue element="contributor" qualifier="author">
					<xsl:value-of select="."/>
				</dcvalue>
			</xsl:for-each>

    
			<dcvalue element="type" qualifier="none">		
				<xsl:if test="$leader7='c'">
					<xsl:attribute name="collection">yes</xsl:attribute>
				</xsl:if>

				<xsl:if test="$leader6='d' or $leader6='f' or $leader6='p' or $leader6='t'">
					<xsl:attribute name="manuscript">yes</xsl:attribute>
				</xsl:if>

				<xsl:choose>
					<xsl:when test="$leader6='a' or $leader6='t'">text</xsl:when>
					<xsl:when test="$leader6='e' or $leader6='f'">cartographic</xsl:when>
					<xsl:when test="$leader6='c' or $leader6='d'">notated music</xsl:when>
					<xsl:when test="$leader6='i' or $leader6='j'">sound recording</xsl:when>
					<xsl:when test="$leader6='k'">still image</xsl:when>
					<xsl:when test="$leader6='g'">moving image</xsl:when>
					<xsl:when test="$leader6='r'">three dimensional object</xsl:when>
					<xsl:when test="$leader6='m'">software, multimedia</xsl:when>
					<xsl:when test="$leader6='p'">mixed material</xsl:when>
				</xsl:choose>
			</dcvalue>

			<xsl:for-each select="marc:datafield[@tag=655]">
				<dcvalue element="type" qualifier="none">
					<xsl:value-of select="."/>
				</dcvalue>
			</xsl:for-each>

			<xsl:for-each select="marc:datafield[@tag=260]">
				<dcvalue element="publisher" qualifier="none">
					<xsl:call-template name="subfieldSelect">
						<xsl:with-param name="codes">ab</xsl:with-param>
					</xsl:call-template>
				</dcvalue>
			</xsl:for-each>

			<xsl:for-each select="marc:datafield[@tag=260]/marc:subfield[@code='c']">
				<dcvalue element="date" qualifier="none">
					<xsl:value-of select="."/>
				</dcvalue>				
			</xsl:for-each>

			<dcvalue element="language" qualifier="iso">
				<xsl:value-of select="substring($controlField008,36,3)"/>
			</dcvalue>

			<xsl:for-each select="marc:datafield[@tag=856]/marc:subfield[@code='q']">
				<dcvalue element="format" qualifier="none">
					<xsl:value-of select="."/>
				</dcvalue>
			</xsl:for-each>

			<xsl:for-each select="marc:datafield[@tag=520]">
				<dcvalue element="description" qualifier="none">
					<xsl:value-of select="marc:subfield[@code='a']"/>
				</dcvalue>
			</xsl:for-each>

			<xsl:for-each select="marc:datafield[@tag=521]">
				<dcvalue element="description" qualifier="none">
					<xsl:value-of select="marc:subfield[@code='a']"/>
				</dcvalue>
			</xsl:for-each>

			<xsl:for-each select="marc:datafield[500&lt;=@tag][@tag&lt;=599][not(@tag=506 or @tag=530 or @tag=540 or @tag=546)]">
				<dcvalue element="description" qualifier="none">
					<xsl:value-of select="marc:subfield[@code='a']"/>
				</dcvalue>
			</xsl:for-each>

			<xsl:for-each select="marc:datafield[@tag=600]">
				<dcvalue element="subject" qualifier="none">
					<xsl:call-template name="subfieldSelect">
						<xsl:with-param name="codes">abcdq</xsl:with-param>
					</xsl:call-template>
				</dcvalue>
			</xsl:for-each>

			<xsl:for-each select="marc:datafield[@tag=610]">
				<dcvalue element="subject" qualifier="none">
					<xsl:call-template name="subfieldSelect">
						<xsl:with-param name="codes">abcdq</xsl:with-param>
					</xsl:call-template>
				</dcvalue>
			</xsl:for-each>

			<xsl:for-each select="marc:datafield[@tag=611]">
				<dcvalue element="subject" qualifier="none">
					<xsl:call-template name="subfieldSelect">
						<xsl:with-param name="codes">abcdq</xsl:with-param>
					</xsl:call-template>
				</dcvalue>
			</xsl:for-each>
		
			<xsl:for-each select="marc:datafield[@tag=630]">
				<dcvalue element="subject" qualifier="none">
					<xsl:call-template name="subfieldSelect">
						<xsl:with-param name="codes">abcdq</xsl:with-param>
					</xsl:call-template>
				</dcvalue>
			</xsl:for-each>

			<xsl:for-each select="marc:datafield[@tag=650]">
				<dcvalue element="subject" qualifier="none">
					<xsl:call-template name="subfieldSelect">
						<xsl:with-param name="codes">abcdq</xsl:with-param>
					</xsl:call-template>
				</dcvalue>
			</xsl:for-each>

			<xsl:for-each select="marc:datafield[@tag=653]">
				<dcvalue element="subject" qualifier="none">
					<xsl:call-template name="subfieldSelect">
						<xsl:with-param name="codes">abcdq</xsl:with-param>
					</xsl:call-template>
				</dcvalue>
			</xsl:for-each>

			<xsl:for-each select="marc:datafield[@tag=752]">
				<dcvalue element="coverage" qualifier="none">
					<xsl:call-template name="subfieldSelect">
						<xsl:with-param name="codes">abcd</xsl:with-param>
					</xsl:call-template>
				</dcvalue>
			</xsl:for-each>

			

			<xsl:for-each select="marc:datafield[@tag=760]|marc:datafield[@tag=762]|marc:datafield[@tag=765]|marc:datafield[@tag=767]|marc:datafield[@tag=770]|marc:datafield[@tag=772]|marc:datafield[@tag=773]|marc:datafield[@tag=774]|marc:datafield[@tag=775]|marc:datafield[@tag=776]|marc:datafield[@tag=777]|marc:datafield[@tag=780]|marc:datafield[@tag=785]|marc:datafield[@tag=786]|marc:datafield[@tag=787]">
				<dcvalue element="relation" qualifier="none">
					<xsl:call-template name="subfieldSelect">
						<xsl:with-param name="codes">ot</xsl:with-param>
					</xsl:call-template>
				</dcvalue>	
			</xsl:for-each>

			<xsl:for-each select="marc:datafield[@tag=856]">
				<dcvalue element="identifier" qualifier="none">
					<xsl:value-of select="marc:subfield[@code='u']"/>
				</dcvalue>
			</xsl:for-each>

			<xsl:for-each select="marc:datafield[@tag=506]">
				<dcvalue element="rights" qualifier="none">
					<xsl:value-of select="marc:subfield[@code='a']"/>
				</dcvalue>
			</xsl:for-each>

			<xsl:for-each select="marc:datafield[@tag=540]">
				<dcvalue element="rights" qualifier="none">
					<xsl:value-of select="marc:subfield[@code='a']"/>
				</dcvalue>
			</xsl:for-each>
			
	
	</xsl:template>
	
</xsl:stylesheet><!-- Stylus Studio meta-information - (c)1998-2002 eXcelon Corp.
<metaInformation>
<scenarios ><scenario default="no" name="MODS Website Samples" userelativepaths="yes" externalpreview="no" url="..\xml\MARC21slim\modswebsitesamples.xml" htmlbaseurl="" processortype="internal" commandline="" additionalpath="" additionalclasspath="" postprocessortype="none" postprocesscommandline="" postprocessadditionalpath="" postprocessgeneratedext=""/><scenario default="no" name="Ray Charles" userelativepaths="yes" externalpreview="no" url="..\xml\MARC21slim\raycharles.xml" htmlbaseurl="" processortype="internal" commandline="" additionalpath="" additionalclasspath="" postprocessortype="none" postprocesscommandline="" postprocessadditionalpath="" postprocessgeneratedext=""/><scenario default="yes" name="s6" userelativepaths="yes" externalpreview="no" url="..\ifla\sally6.xml" htmlbaseurl="" processortype="internal" commandline="" additionalpath="" additionalclasspath="" postprocessortype="none" postprocesscommandline="" postprocessadditionalpath="" postprocessgeneratedext=""/><scenario default="no" name="s7" userelativepaths="yes" externalpreview="no" url="..\ifla\sally7.xml" htmlbaseurl="" processortype="internal" commandline="" additionalpath="" additionalclasspath="" postprocessortype="none" postprocesscommandline="" postprocessadditionalpath="" postprocessgeneratedext=""/><scenario default="no" name="s12" userelativepaths="yes" externalpreview="no" url="..\ifla\sally12.xml" htmlbaseurl="" processortype="internal" commandline="" additionalpath="" additionalclasspath="" postprocessortype="none" postprocesscommandline="" postprocessadditionalpath="" postprocessgeneratedext=""/></scenarios><MapperInfo srcSchemaPath="" srcSchemaRoot="" srcSchemaPathIsRelative="yes" srcSchemaInterpretAsXML="no" destSchemaPath="" destSchemaRoot="" destSchemaPathIsRelative="yes" destSchemaInterpretAsXML="no"/>
</metaInformation>
-->